# Index of /pub/DDSM/cases/normals/normal_08/case4606 on figment.csee.usf.edu:21

      1999 May 28        File        D-4606-1.ics  (514 bytes)
      1999 Apr 28        File        D_4606_1.LEFT_CC.LJPEG  (36870948 bytes)
      1999 Apr 28        File        D_4606_1.LEFT_MLO.LJPEG  (32339081 bytes)
      1999 Apr 28        File        D_4606_1.RIGHT_CC.LJPEG  (32665695 bytes)
      1999 Apr 28        File        D_4606_1.RIGHT_MLO.LJPEG  (34537730 bytes)
      1999 Apr 28        File        TAPE_D_4606_1.COMB.16_PGM  (934518 bytes)